stalker.core.models.Department
==============================

.. inheritance-diagram::
     stalker.core.models.Department
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Department
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Department.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Department.code
      ~Department.created_by
      ~Department.date_created
      ~Department.date_updated
      ~Department.description
      ~Department.lead
      ~Department.members
      ~Department.name
      ~Department.nice_name
      ~Department.notes
      ~Department.tags
      ~Department.type
      ~Department.updated_by
   
   